@@ -49,6 +49,10 @@ serve just one of them:
     our $host = "campaignwiki.org";
     use App::Phoebe::Ijirait;
 
+The help file, if you have one, is F<ijirait-help.gmi> in your wiki data
+directory. Feel free to get a copy of
+L<gemini://transjovian.org/ijiraq/page/Help>.
+
 =cut
 
 package App::Phoebe::Ijirait;
@@ -57,6 +61,7 @@ use Modern::Perl;
 use Encode qw(encode_utf8 decode_utf8);
 use File::Slurper qw(read_binary write_binary read_text);
 use Mojo::JSON qw(decode_json encode_json);
+use Mojo::Util qw(gzip);
 use List::Util qw(first);
 use Graph::Easy;
 use URI::Escape;
@@ -81,6 +86,7 @@ our $commands = {
   look     => \&look,
   type     => \&type,
   save     => \&save,
+  backup   => \&backup,
   say      => \&speak, # can't use say!
   who      => \&who,
   go       => \&go,
@@ -535,6 +541,14 @@ sub cleanup() {
   }
 }
 
+sub backup() {
+  my $stream = shift;
+  my $bytes = encode_json $data;
+  $bytes =~ s/"fingerprint":"[^"]+"/"fingerprint":""/g;
+  success($stream, "application/json+gzip");
+  $stream->write(gzip $bytes);
+}
+
 sub who {
   my ($stream) = @_;
   my $now = time;
